@@ -717,6 +717,10 @@ BEGIN {
     
 1;
 
+__END__
+
+=encoding UTF-8
+
 =head1 NAME
 
 Jemplate::Directive - Jemplate Code Generating Backend
@@ -745,7 +749,7 @@ Ingy döt Net <ingy@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2008. Ingy döt Net. All rights reserved.
+Copyright (c) 2006-2014. Ingy döt Net. All rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
