@@ -13,7 +13,7 @@ compiled Jemplate templates.
 
 AUTHOR - Ingy döt Net <ingy@cpan.org>
 
-Copyright 2006,2008 Ingy döt Net.
+Copyright 2006-2014 Ingy döt Net.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
@@ -36,11 +36,6 @@ Jemplate.process = function() {
     return jemplate.process.apply(jemplate, arguments);
 }
 
-// commonjs export style
-if (typeof(exports) == "object") {
-    exports.Jemplate = Jemplate;
-}
-
 ;(function(){
 
 if (! Jemplate.templateMap)
@@ -2802,6 +2797,10 @@ function JJJ(obj) {
 
 1;
 
+__END__
+
+=encoding UTF-8
+
 =head1 NAME
 
 Jemplate::Runtime - Perl Module containing the Jemplate JavaScript Runtime
@@ -2841,7 +2840,7 @@ head2 xxx
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008. Ingy döt Net.
+Copyright (c) 2014. Ingy döt Net.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
